diff --git a/src/Fl_Window_shape.cxx b/src/Fl_Window_shape.cxx
index 7675053..d9dc7c8 100644
--- a/src/Fl_Window_shape.cxx
+++ b/src/Fl_Window_shape.cxx
@@ -369,10 +369,52 @@ void Fl_Window::draw() {
   //   Other windows do not draw their labels at all, unless drawn by their
   //   parent widgets or by special draw() methods (derived classes).
 
+#if USE_X11
+  int restore_clip = 0;			// STR 3206 (see below)
+#endif	// USE_X11
+
   if (damage() & ~FL_DAMAGE_CHILD) {	 // draw the entire thing
     draw_box(box(),0,0,w(),h(),color()); // draw box with x/y = 0
 
     if (image() && (align() & FL_ALIGN_INSIDE)) { // draw the image only
+
+      // STR #3206: "(Re-)drawing artefacts with scheme plastic ..."
+      //
+      // Under Unix/Linux (X11) the Fl_Pixmap drawing code needs
+      // a bit mask to draw the image. This can't be combined with the
+      // active clip region [1], hence /that/ code sets up its own clip
+      // region using a potentially larger rectangular area (the clip box).
+      // We must do the same here (maybe resulting in drawing more
+      // than necessary) to make sure that the widgets get drawn
+      // properly as well.
+      //
+      // [1] See Fl_Xlib_Graphics_Driver::draw(Fl_Pixmap *pxm, ...).
+      //
+      // Note 1: In the worst case this can result in drawing the whole
+      // window if (for instance) the top left and the bottom right corner
+      // are exposed. This can happen if the window is activated (focused)
+      // after only these parts have been occluded by other windows.
+      //
+      // Note 2: Modern compositing window managers save the window's
+      // contents anyway and don't send expose events at all, hence this
+      // doesn't matter with these modern WM's, such as Unity.
+      //
+      // AlbrechtS, Mar 12, 2015
+
+#if USE_X11
+
+      int xc, yc, wc, hc;
+      fl_clip_box(0, 0, w(), h(), xc, yc, wc, hc);
+      printf ("fl_clip_box(%d,%d,%d,%d,...) -> (%d,%d,%d,%d)\n",
+	0, 0, w(), h(), xc, yc, wc, hc);
+      if (wc > 0 && hc > 0) {
+	fl_push_no_clip();		// reset clip region
+	fl_push_clip(xc, yc, wc, hc);	// set new clip region
+	restore_clip = 1;
+      }
+
+#endif	// USE_X11
+
       Fl_Label l1;
       memset(&l1,0,sizeof(l1));
       l1.align_ = align();
@@ -384,6 +426,13 @@ void Fl_Window::draw() {
   }
   draw_children();
 
+#if USE_X11
+if (restore_clip) {
+  fl_pop_clip();
+  fl_pop_clip();
+}
+#endif	// USE_X11
+
 #ifdef __APPLE_QUARTZ__
   // on OS X, windows have no frame. Before OS X 10.7, to resize a window, we drag the lower right
   // corner. This code draws a little ribbed triangle for dragging.
